debug

package module
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 30, 2020 License: MIT Imports: 13 Imported by: 2

README

debug

GoDoc

Golang's library helps to debug your code

Dependencies
NONE
Install
go get github.com/webnice/debug/v1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Dumper

func Dumper(idl ...interface{})

Dumper Dump all variables to STDOUT

func DumperByte

func DumperByte(idl ...interface{}) []byte

DumperByte Dump all variables to []byte

func DumperFile

func DumperFile(idl ...interface{})

DumperFile Dump all variables to file. Name file is the same program name and .txt at extension

func DumperString

func DumperString(idl ...interface{}) string

DumperString Dump all variables to string

func FileSave

func FileSave(body []byte, file, path string) (err error)

FileSave Save string to file. Create file if not exist and append file if exist. If file name is not specified, create file name is the same program name and .txt at extension

func Nop

func Nop()

Nop Empty function. if set environment value DEBUG_CALLS=1 all calls Nop() displayed filename and line

func SeeCallStack

func SeeCallStack(v bool)

SeeCallStack Enable or disable call stack trace

Types

This section is empty.

Jump to