Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DumperByte ¶
func DumperByte(idl ...interface{}) []byte
DumperByte Dump all variables to []byte
func DumperFile ¶
func DumperFile(idl ...interface{})
DumperFile Dump all variables to file. Name file is the same program name and .txt at extension
func DumperString ¶
func DumperString(idl ...interface{}) string
DumperString Dump all variables to string
func FileSave ¶
FileSave Save string to file. Create file if not exist and append file if exist. If file name is not specified, create file name is the same program name and .txt at extension
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.